@@ -26,7 +26,7 @@ pub use self::{
     register::{RegisterCmd, RegisterRead, RegisterWrite},
 };
 
-use crate::messaging::MessageId;
+use crate::messaging::{data::Error as ErrorMessage, MessageId};
 use crate::types::{
     register::{Entry, EntryHash, Permissions, Policy, Register},
     Chunk, PublicKey,
@@ -142,6 +142,38 @@ impl QueryResponse {
             GetRegisterUserPermissions(result) => result.is_ok(),
         }
     }
+
+    /// Returns true if data was not found
+    pub fn failed_with_data_not_found(&self) -> bool {
+        use QueryResponse::*;
+
+        match self {
+            GetChunk(result) => match result {
+                Ok(_) => false,
+                Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
+            },
+            GetRegister(result) => match result {
+                Ok(_) => false,
+                Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
+            },
+            GetRegisterOwner(result) => match result {
+                Ok(_) => false,
+                Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
+            },
+            ReadRegister(result) => match result {
+                Ok(_) => false,
+                Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
+            },
+            GetRegisterPolicy(result) => match result {
+                Ok(_) => false,
+                Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
+            },
+            GetRegisterUserPermissions(result) => match result {
+                Ok(_) => false,
+                Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
+            },
+        }
+    }
 }
 
 /// Error type for an attempted conversion from a [`QueryResponse`] variant to an expected wrapped
