@@ -12,37 +12,36 @@ use bls::PublicKey as BlsPublicKey;
 use ed25519_dalek::{PublicKey, Signature};
 use hex_fmt::HexFmt;
 use serde::{Deserialize, Serialize};
-use std::{
-    borrow::Borrow,
-    collections::BTreeSet,
-    fmt::{self, Debug, Formatter},
-};
+use std::{borrow::Borrow, collections::BTreeSet, fmt};
 use xor_name::{Prefix, XorName};
 
 /// SHA3-256 hash digest.
 type Digest256 = [u8; 32];
 
 /// Unique identifier of a DKG session.
-#[derive(Copy, Clone, Eq, PartialEq, Hash, Serialize, Deserialize)]
+#[derive(Copy, Clone, Eq, PartialEq, Hash, Serialize, Deserialize, custom_debug::Debug)]
 pub struct DkgKey {
     /// A hash of the peers and prefix of the specific session.
+    #[debug(with = "Self::fmt_hash")]
     pub hash: Digest256,
     /// The generation, as in the length of the section chain main branch.
     pub generation: u64,
 }
 
-impl Debug for DkgKey {
-    fn fmt(&self, f: &mut Formatter) -> fmt::Result {
-        write!(f, "DkgKey({:10}/{})", HexFmt(&self.hash), self.generation)
+impl DkgKey {
+    fn fmt_hash(hash: &Digest256, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{:0.10}", HexFmt(hash))
     }
 }
 
 /// One signed failure for a DKG round by a given PublicKey
-#[derive(Copy, Clone, Eq, PartialEq, Debug, Serialize, Deserialize)]
+#[derive(Copy, Clone, Eq, PartialEq, Serialize, Deserialize, custom_debug::Debug)]
 pub struct DkgFailureSig {
     #[allow(missing_docs)]
+    #[debug(with = "crate::types::PublicKey::fmt_ed25519")]
     pub public_key: PublicKey,
     #[allow(missing_docs)]
+    #[debug(with = "crate::types::Signature::fmt_ed25519")]
     pub signature: Signature,
 }
 
