@@ -7,24 +7,21 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::messaging::{
-    data::{
-        ChunkRead, ChunkWrite, CmdError, DataCmd as NodeDataCmd, DataExchange,
-        DataQuery as NodeDataQuery, Error, Result,
-    },
+    data::{ChunkRead, ChunkWrite, DataCmd, DataExchange, DataQuery, Result},
     DataSigned, EndUser,
 };
-use crate::types::{Chunk, ChunkAddress, PublicKey, Signature};
+use crate::types::{Chunk, PublicKey};
 use serde::{Deserialize, Serialize};
 use xor_name::XorName;
 
-///
+/// Command message sent among nodes
 #[allow(clippy::large_enum_variant)]
 #[derive(Debug, Eq, PartialEq, Clone, Serialize, Deserialize)]
 pub enum NodeCmd {
     /// Metadata is handled by Elders
     Metadata {
         /// The contianed command
-        cmd: NodeDataCmd,
+        cmd: DataCmd,
         /// Requester pk and signature
         data_signed: DataSigned,
         /// Message source
@@ -39,14 +36,6 @@ pub enum NodeCmd {
         /// Message source
         origin: EndUser,
     },
-    /// Cmds related to the running of a node.
-    System(NodeSystemCmd),
-}
-
-/// Cmds related to the running of a node.
-#[allow(clippy::large_enum_variant)]
-#[derive(Debug, Eq, PartialEq, Clone, Serialize, Deserialize)]
-pub enum NodeSystemCmd {
     /// Notify Elders on nearing max capacity
     StorageFull {
         /// Node Id
@@ -54,7 +43,7 @@ pub enum NodeSystemCmd {
         /// Section to which the message needs to be sent to. (NB: this is the section of the node id).
         section: XorName,
     },
-    /// Replicate a given chunk at an Adult
+    /// Replicate a given chunk at an Adult (sent from elders on receipt of RepublishChunk)
     ReplicateChunk(Chunk),
     /// Tells the Elders to re-publish a chunk in the data section
     RepublishChunk(Chunk),
@@ -66,33 +55,13 @@ pub enum NodeSystemCmd {
     },
 }
 
-// -------------- Node Events --------------
-
-///
-#[allow(clippy::large_enum_variant)]
-#[derive(Debug, Eq, PartialEq, Clone, Serialize, Deserialize)]
-pub enum NodeEvent {
-    /// Replication completed event, emitted by a node, received by elders.
-    ReplicationCompleted {
-        ///
-        chunk: ChunkAddress,
-        /// The Elder's accumulated signature
-        /// over the chunk address. This is sent back
-        /// to them so that any uninformed Elder knows
-        /// that this is all good.
-        proof: Signature,
-    },
-    /// Adults ack read/write of chunks as to convey responsivity.
-    ChunkWriteHandled(Result<(), CmdError>),
-}
-
 /// Query originating at a node
 #[derive(Debug, Eq, PartialEq, Clone, Serialize, Deserialize)]
 pub enum NodeQuery {
     /// Metadata is handled by Elders
     Metadata {
         /// The actual query message
-        query: NodeDataQuery,
+        query: DataQuery,
         /// Client signature
         data_signed: DataSigned,
         /// The user that has initiated this query
@@ -114,23 +83,3 @@ pub enum NodeQueryResponse {
     /// Elder to Adult Get.
     GetChunk(Result<Chunk>),
 }
-
-///
-#[allow(clippy::large_enum_variant)]
-#[derive(Debug, Hash, Eq, PartialEq, Clone, Serialize, Deserialize)]
-pub enum NodeCmdError {
-    ///
-    Data(NodeDataError),
-}
-
-///
-#[derive(Debug, Hash, Eq, PartialEq, Clone, Serialize, Deserialize)]
-pub enum NodeDataError {
-    ///
-    ChunkReplication {
-        ///
-        head_address: ChunkAddress,
-        ///
-        error: Error,
-    },
-}
